@@ -256,7 +256,7 @@ async fn main_async(opts: WorkerConfig, recv_stop: Receiver<()>) -> surf::Result
                             let reward_speed = 2u128.pow(my_difficulty as u32)
                                 / (snap.current_header().height.0 + 10 - data.height.0) as u128;
                             let reward = themelio_stf::calculate_reward(
-                                reward_speed,
+                                reward_speed * 100,
                                 snap.current_header().dosc_speed,
                                 my_difficulty as u32,
                                 true
